==> RsSmw-4.90.49.53-py3-none-any.whl: RsSmw/Implementations/Source/Bb/Gnss/Sv/Sbas/Egnos/Nmessage/Nav/Time/Conversion/Utc/Azero.py <==
from .............Internal.Core import Core
from .............Internal.CommandsGroup import CommandsGroup
from .............Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Azero:
	"""Azero commands group definition. 2 total commands, 0 Sub-groups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("azero", core, parent)

	def get_unscaled(self) -> float:
		"""SCPI: [SOURce<HW>]:BB:GNSS:SV:SBAS:EGNOS:NMESsage:NAV:TIME:CONVersion:UTC:AZERo:UNSCaled \n
		Snippet: value: float = driver.source.bb.gnss.sv.sbas.egnos.nmessage.nav.time.conversion.utc.azero.get_unscaled() \n
		Sets the parameter A0. \n
			:return: a_0: integer Range: -32768 to 32767
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:GNSS:SV:SBAS:EGNOS:NMESsage:NAV:TIME:CONVersion:UTC:AZERo:UNSCaled?')
		return Conversions.str_to_float(response)

	def set_unscaled(self, a_0: float) -> None:
		"""SCPI: [SOURce<HW>]:BB:GNSS:SV:SBAS:EGNOS:NMESsage:NAV:TIME:CONVersion:UTC:AZERo:UNSCaled \n
		Snippet: driver.source.bb.gnss.sv.sbas.egnos.nmessage.nav.time.conversion.utc.azero.set_unscaled(a_0 = 1.0) \n
		Sets the parameter A0. \n
			:param a_0: integer Range: -32768 to 32767
		"""
		param = Conversions.decimal_value_to_str(a_0)
		self._core.io.write(f'SOURce<HwInstance>:BB:GNSS:SV:SBAS:EGNOS:NMESsage:NAV:TIME:CONVersion:UTC:AZERo:UNSCaled {param}')

	def get_value(self) -> int:
		"""SCPI: [SOURce<HW>]:BB:GNSS:SV:SBAS:EGNOS:NMESsage:NAV:TIME:CONVersion:UTC:AZERo \n
		Snippet: value: int = driver.source.bb.gnss.sv.sbas.egnos.nmessage.nav.time.conversion.utc.azero.get_value() \n
		Sets the parameter A0. \n
			:return: a_0: integer Range: -32768 to 32767
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:GNSS:SV:SBAS:EGNOS:NMESsage:NAV:TIME:CONVersion:UTC:AZERo?')
		return Conversions.str_to_int(response)

	def set_value(self, a_0: int) -> None:
		"""SCPI: [SOURce<HW>]:BB:GNSS:SV:SBAS:EGNOS:NMESsage:NAV:TIME:CONVersion:UTC:AZERo \n
		Snippet: driver.source.bb.gnss.sv.sbas.egnos.nmessage.nav.time.conversion.utc.azero.set_value(a_0 = 1) \n
		Sets the parameter A0. \n
			:param a_0: integer Range: -32768 to 32767
		"""
		param = Conversions.decimal_value_to_str(a_0)
		self._core.io.write(f'SOURce<HwInstance>:BB:GNSS:SV:SBAS:EGNOS:NMESsage:NAV:TIME:CONVersion:UTC:AZERo {param}')

==> RsSmw-5.0.44.58-py3-none-any.whl: RsSmw/Implementations/Source/Bb/Gnss/Sv/Sbas/Egnos/Nmessage/Nav/Time/Conversion/Utc/Azero.py <==
from .............Internal.Core import Core
from .............Internal.CommandsGroup import CommandsGroup
from .............Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Azero:
	"""Azero commands group definition. 2 total commands, 0 Subgroups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("azero", core, parent)

	def get_unscaled(self) -> float:
		"""SCPI: [SOURce<HW>]:BB:GNSS:SV:SBAS:EGNOS:NMESsage:NAV:TIME:CONVersion:UTC:AZERo:UNSCaled \n
		Snippet: value: float = driver.source.bb.gnss.sv.sbas.egnos.nmessage.nav.time.conversion.utc.azero.get_unscaled() \n
		Sets the parameter A0. \n
			:return: a_0: integer Range: -32768 to 32767
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:GNSS:SV:SBAS:EGNOS:NMESsage:NAV:TIME:CONVersion:UTC:AZERo:UNSCaled?')
		return Conversions.str_to_float(response)

	def set_unscaled(self, a_0: float) -> None:
		"""SCPI: [SOURce<HW>]:BB:GNSS:SV:SBAS:EGNOS:NMESsage:NAV:TIME:CONVersion:UTC:AZERo:UNSCaled \n
		Snippet: driver.source.bb.gnss.sv.sbas.egnos.nmessage.nav.time.conversion.utc.azero.set_unscaled(a_0 = 1.0) \n
		Sets the parameter A0. \n
			:param a_0: integer Range: -32768 to 32767
		"""
		param = Conversions.decimal_value_to_str(a_0)
		self._core.io.write(f'SOURce<HwInstance>:BB:GNSS:SV:SBAS:EGNOS:NMESsage:NAV:TIME:CONVersion:UTC:AZERo:UNSCaled {param}')

	def get_value(self) -> int:
		"""SCPI: [SOURce<HW>]:BB:GNSS:SV:SBAS:EGNOS:NMESsage:NAV:TIME:CONVersion:UTC:AZERo \n
		Snippet: value: int = driver.source.bb.gnss.sv.sbas.egnos.nmessage.nav.time.conversion.utc.azero.get_value() \n
		Sets the parameter A0. \n
			:return: a_0: integer Range: -32768 to 32767
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:GNSS:SV:SBAS:EGNOS:NMESsage:NAV:TIME:CONVersion:UTC:AZERo?')
		return Conversions.str_to_int(response)

	def set_value(self, a_0: int) -> None:
		"""SCPI: [SOURce<HW>]:BB:GNSS:SV:SBAS:EGNOS:NMESsage:NAV:TIME:CONVersion:UTC:AZERo \n
		Snippet: driver.source.bb.gnss.sv.sbas.egnos.nmessage.nav.time.conversion.utc.azero.set_value(a_0 = 1) \n
		Sets the parameter A0. \n
			:param a_0: integer Range: -32768 to 32767
		"""
		param = Conversions.decimal_value_to_str(a_0)
		self._core.io.write(f'SOURce<HwInstance>:BB:GNSS:SV:SBAS:EGNOS:NMESsage:NAV:TIME:CONVersion:UTC:AZERo {param}')
